Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type UnitStatus ¶
type UnitStatus struct {
Name string // The primary unit name as string
Description string // The human readable description string
ActiveState string // The active state (i.e. whether the unit is currently started or not)
LoadState string // The load state (i.e. whether the unit file has been loaded successfully)
SubState string // The sub state (a more fine-grained version of the active state that is specific to the unit type, which the active state is not)
}
func Status ¶
func Status(name ...string) ([]UnitStatus, error)
func (UnitStatus) String ¶
func (us UnitStatus) String() string
Click to show internal directories.
Click to hide internal directories.